CHANGES
=======

0.6.0 (2013-10-02)
------------------

- view mode options.
- tmux mode.
- minimal horizontal view.
- stack view.
- normal vertical view.
- minimal vertical view.

0.1.0 (2013-09-30)
------------------

- initial version.

